@@ -3,8 +3,9 @@ Main interface for elasticache service.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.elasticache import (
+    from mypy_boto3_elasticache import (
         CacheClusterAvailableWaiter,
         CacheClusterDeletedWaiter,
         Client,
@@ -26,7 +27,7 @@ Usage::
         ElastiCacheClient,
         ReplicationGroupAvailableWaiter,
         ReplicationGroupDeletedWaiter,
-        )
+    )
 
     session = boto3.Session()
 
@@ -53,8 +54,9 @@ Usage::
     describe_service_updates_paginator: DescribeServiceUpdatesPaginator = client.get_paginator("describe_service_updates")
     describe_snapshots_paginator: DescribeSnapshotsPaginator = client.get_paginator("describe_snapshots")
     describe_update_actions_paginator: DescribeUpdateActionsPaginator = client.get_paginator("describe_update_actions")
+    ```
 """
-from mypy_boto3_elasticache.client import ElastiCacheClient as Client, ElastiCacheClient
+from mypy_boto3_elasticache.client import ElastiCacheClient
 from mypy_boto3_elasticache.paginator import (
     DescribeCacheClustersPaginator,
     DescribeCacheEngineVersionsPaginator,
@@ -79,6 +81,8 @@ from mypy_boto3_elasticache.waiter import (
     ReplicationGroupDeletedWaiter,
 )
 
+Client = ElastiCacheClient
+
 
 __all__ = (
     "CacheClusterAvailableWaiter",
