@@ -1,10 +1,14 @@
+# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 """
 Main interface for elasticache service client waiters.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.elasticache import (
+
+    from mypy_boto3_elasticache import ElastiCacheClient
+    from mypy_boto3_elasticache.waiter import (
         CacheClusterAvailableWaiter,
         CacheClusterDeletedWaiter,
         ReplicationGroupAvailableWaiter,
@@ -17,12 +21,11 @@ Usage::
     cache_cluster_deleted_waiter: CacheClusterDeletedWaiter = client.get_waiter("cache_cluster_deleted")
     replication_group_available_waiter: ReplicationGroupAvailableWaiter = client.get_waiter("replication_group_available")
     replication_group_deleted_waiter: ReplicationGroupDeletedWaiter = client.get_waiter("replication_group_deleted")
+    ```
 """
-# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
-from typing import TYPE_CHECKING
 from botocore.waiter import Waiter as Boto3Waiter
-from mypy_boto3_elasticache.type_defs import WaiterConfigTypeDef
 
+from mypy_boto3_elasticache.type_defs import WaiterConfigTypeDef
 
 __all__ = (
     "CacheClusterAvailableWaiter",
@@ -34,7 +37,7 @@ __all__ = (
 
 class CacheClusterAvailableWaiter(Boto3Waiter):
     """
-    [Waiter.CacheClusterAvailable documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/elasticache.html#ElastiCache.Waiter.CacheClusterAvailable)
+    [Waiter.CacheClusterAvailable documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.21/reference/services/elasticache.html#ElastiCache.Waiter.CacheClusterAvailable)
     """
 
     def wait(
@@ -47,13 +50,13 @@ class CacheClusterAvailableWaiter(Boto3Waiter):
         WaiterConfig: WaiterConfigTypeDef = None,
     ) -> None:
         """
-        [CacheClusterAvailable.wait documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/elasticache.html#ElastiCache.Waiter.CacheClusterAvailable.wait)
+        [CacheClusterAvailable.wait documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.21/reference/services/elasticache.html#ElastiCache.Waiter.CacheClusterAvailable.wait)
         """
 
 
 class CacheClusterDeletedWaiter(Boto3Waiter):
     """
-    [Waiter.CacheClusterDeleted documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/elasticache.html#ElastiCache.Waiter.CacheClusterDeleted)
+    [Waiter.CacheClusterDeleted documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.21/reference/services/elasticache.html#ElastiCache.Waiter.CacheClusterDeleted)
     """
 
     def wait(
@@ -66,13 +69,13 @@ class CacheClusterDeletedWaiter(Boto3Waiter):
         WaiterConfig: WaiterConfigTypeDef = None,
     ) -> None:
         """
-        [CacheClusterDeleted.wait documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/elasticache.html#ElastiCache.Waiter.CacheClusterDeleted.wait)
+        [CacheClusterDeleted.wait documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.21/reference/services/elasticache.html#ElastiCache.Waiter.CacheClusterDeleted.wait)
         """
 
 
 class ReplicationGroupAvailableWaiter(Boto3Waiter):
     """
-    [Waiter.ReplicationGroupAvailable documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/elasticache.html#ElastiCache.Waiter.ReplicationGroupAvailable)
+    [Waiter.ReplicationGroupAvailable documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.21/reference/services/elasticache.html#ElastiCache.Waiter.ReplicationGroupAvailable)
     """
 
     def wait(
@@ -83,13 +86,13 @@ class ReplicationGroupAvailableWaiter(Boto3Waiter):
         WaiterConfig: WaiterConfigTypeDef = None,
     ) -> None:
         """
-        [ReplicationGroupAvailable.wait documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/elasticache.html#ElastiCache.Waiter.ReplicationGroupAvailable.wait)
+        [ReplicationGroupAvailable.wait documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.21/reference/services/elasticache.html#ElastiCache.Waiter.ReplicationGroupAvailable.wait)
         """
 
 
 class ReplicationGroupDeletedWaiter(Boto3Waiter):
     """
-    [Waiter.ReplicationGroupDeleted documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/elasticache.html#ElastiCache.Waiter.ReplicationGroupDeleted)
+    [Waiter.ReplicationGroupDeleted documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.21/reference/services/elasticache.html#ElastiCache.Waiter.ReplicationGroupDeleted)
     """
 
     def wait(
@@ -100,5 +103,5 @@ class ReplicationGroupDeletedWaiter(Boto3Waiter):
         WaiterConfig: WaiterConfigTypeDef = None,
     ) -> None:
         """
-        [ReplicationGroupDeleted.wait documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/elasticache.html#ElastiCache.Waiter.ReplicationGroupDeleted.wait)
+        [ReplicationGroupDeleted.wait documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.21/reference/services/elasticache.html#ElastiCache.Waiter.ReplicationGroupDeleted.wait)
         """
